@@ -302,19 +302,26 @@ impl Handler {
     /// ready and idle), the `Target` sends its newly created `Page` as response
     /// to the initiator (`tx`) of the `CreateTargetParams` request.
     fn create_page(&mut self, params: CreateTargetParams, tx: OneshotSender<Result<Page>>) {
-        let method = params.identifier();
-        match serde_json::to_value(params) {
-            Ok(params) => match self.conn.submit_command(method.clone(), None, params) {
-                Ok(call_id) => {
-                    self.pending_commands.insert(
-                        call_id,
-                        (PendingRequest::CreateTarget(tx), method, Instant::now()),
-                    );
+        match url::Url::parse(&params.url) {
+            Ok(_) => {
+                let method = params.identifier();
+                match serde_json::to_value(params) {
+                    Ok(params) => match self.conn.submit_command(method.clone(), None, params) {
+                        Ok(call_id) => {
+                            self.pending_commands.insert(
+                                call_id,
+                                (PendingRequest::CreateTarget(tx), method, Instant::now()),
+                            );
+                        }
+                        Err(err) => {
+                            let _ = tx.send(Err(err.into())).ok();
+                        }
+                    },
+                    Err(err) => {
+                        let _ = tx.send(Err(err.into())).ok();
+                    }
                 }
-                Err(err) => {
-                    let _ = tx.send(Err(err.into())).ok();
-                }
-            },
+            }
             Err(err) => {
                 let _ = tx.send(Err(err.into())).ok();
             }
@@ -365,11 +372,7 @@ impl Handler {
 
     /// A new session is attached to a target
     fn on_attached_to_target(&mut self, event: EventAttachedToTarget) {
-        let session = Session::new(
-            event.session_id.clone(),
-            event.target_info.r#type,
-            event.target_info.target_id,
-        );
+        let session = Session::new(event.session_id.clone(), event.target_info.target_id);
         if let Some(target) = self.targets.get_mut(session.target_id()) {
             target.set_session_id(session.session_id().clone())
         }
@@ -528,7 +531,7 @@ impl Stream for Handler {
                 done = false;
             }
 
-            if pin.evict_command_timeout.is_ready(cx) {
+            if pin.evict_command_timeout.poll_ready(cx) {
                 // evict all commands that timed out
                 pin.evict_timed_out_commands(now);
             }
